/*
 *  Copyright (c) 2011 José Luis Vergara <pentalis@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "lightlistitem.h"


LightListItem::LightListItem(QListWidget *parent) :
    QObject(parent), QListWidgetItem(parent)
{
}

LightListItem::LightListItem(const QIcon & icon, const QString & text, QListWidget * parent, int type) :
    QObject(parent), QListWidgetItem(parent)
{
    QListWidgetItem::QListWidgetItem(icon, text, parent, type);
    setIcon(icon);
    setText(text);
}

LightListItem::~LightListItem()
{

}

void LightListItem::setIconColor(QColor color)
{
    QPixmap iconpixmap(16, 16);
    iconpixmap.fill(color);
    setIcon(QIcon(iconpixmap));
}

void LightListItem::setCoordinates(qreal azimuth, qreal altitude)
{
    if (m_azimuth != azimuth)
        m_azimuth = azimuth;
    if (m_altitude != altitude)
        m_altitude = altitude;
    refreshText();
}

void LightListItem::setAzimuth(qreal azimuth)
{
    if (m_azimuth != azimuth)
        m_azimuth = azimuth;
    refreshText();
}

void LightListItem::setAltitude(qreal altitude)
{
    if (m_altitude != altitude)
        m_altitude = altitude;
    refreshText();
}

void LightListItem::refreshText()
{
    QString newtext;
    newtext.append("Azi: ");
    newtext.append(QString::number(m_azimuth, 'g', 3));
    newtext.append("; Alti: ");
    newtext.append(QString::number(m_altitude, 'g', 3));
    setText(newtext);
}
