/*
 *  Copyright (c) 2011 José Luis Vergara <pentalis@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */


#include "wdgphongbumpmap.h"
#include "ui_wdgphongbumpmap.h"


WdgPhongBumpmap::WdgPhongBumpmap(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::WdgPhongBumpmap)
{
    ui->setupUi(this);
}

WdgPhongBumpmap::~WdgPhongBumpmap()
{
    delete ui;
}

void WdgPhongBumpmap::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void WdgPhongBumpmap::on_addLightButton_clicked()
{
    LightSource* newlight = new LightSource(QColor(0, 255, 255, 255), 0, 90, ui->lightStage);
    QPixmap iconpixmap(16, 16);
    iconpixmap.fill(QColor(newlight->color()));

    LightListItem* newlightitem = new LightListItem(QIcon(iconpixmap),
                                                    "newlight");
    newlight->listItem = newlightitem;
    ui->lightsListWidget->addItem(newlightitem);

    QObject::connect(newlight, SIGNAL(moved()),
                     ui->lightStage, SLOT(update()));
    QObject::connect(newlight, SIGNAL(colorChanged(QColor)),
                     newlightitem, SLOT(setIconColor(QColor)));
    QObject::connect(newlight, SIGNAL(orbitMoved(qreal, qreal)),
                     newlightitem, SLOT(setCoordinates(qreal, qreal)));
}

void WdgPhongBumpmap::on_removeLightButton_clicked()
{
    QList<LightSource*> lightSources = ui->lightStage->findChildren<LightSource *>();

    foreach (LightSource* light, lightSources) {
        if (light->isSelected())
        {
            light->listItem->~LightListItem();
            light->~LightSource();
        }
    }

}

